import{cw as n}from"./outputWidgets.781e41f9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="b1a66710-2c53-41e3-af8e-16a343b23e88",e._sentryDebugIdIdentifier="sentry-dbid-b1a66710-2c53-41e3-af8e-16a343b23e88")}catch{}})();const d=(e,r)=>{n.error({message:e,description:r})};export{d as p};
//# sourceMappingURL=popupNotifcation.aa17bce8.js.map
