import{d as c,eB as m,u as e,b as d,c as u,ev as y,f as a,w as o,bg as _,aq as p,ex as g,e as b,eD as x}from"./outputWidgets.781e41f9.js";import"./authorManager.2805bec3.js";import"./index.fc2f40fb.js";import{O as w}from"./organization.ff3609a4.js";import{a as k}from"./asyncComputed.d06d5356.js";import{a as B}from"./Title.bf1f8106.js";import{A as h}from"./index.179a4456.js";import{A}from"./index.b2c1bb4a.js";import{A as C}from"./Text.6168f33a.js";import{C as D}from"./Card.7e708e2a.js";import"./index.cf4c23b9.js";import"./record.71f43d7d.js";import"./pubsub.2273fc34.js";import"./TabPane.6d00c211.js";import"./hasIn.205b6afa.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="958a95af-7711-4336-98d4-e14aa7b086b1",t._sentryDebugIdIdentifier="sentry-dbid-958a95af-7711-4336-98d4-e14aa7b086b1")}catch{}})();const I={key:1},v={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},K=c({__name:"Billing",setup(t){const n=m().params.organizationId,{loading:l,result:f}=k(()=>w.get(n));return(z,N)=>e(l)?(d(),u(e(_),{key:0})):(d(),y("div",I,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(B),{level:3},{default:o(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),a(e(A),{style:{"margin-top":"0"}}),a(e(D),{style:{width:"300px"}},{default:o(()=>{var i,s;return[a(e(C),{type:"secondary"},{default:o(()=>[p("Plan")]),_:1}),b("div",v,x((s=(i=e(f))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{K as default};
//# sourceMappingURL=Billing.30df6db3.js.map
