import{F as t}from"./Form.a1506234.js";import{aL as r,cl as n}from"./outputWidgets.781e41f9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="52c7182d-31ba-4d6b-9813-4af56ba2ee23",e._sentryDebugIdIdentifier="sentry-dbid-52c7182d-31ba-4d6b-9813-4af56ba2ee23")}catch{}})();t.useInjectFormItemContext=r;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.8c1a4b30.js.map
