import{d as k,eB as B,eA as I,G as w,a as h,b as a,c as d,w as o,eK as j,f as n,u as t,ev as l,eC as x,aq as g,eD as z,bq as C,ex as A,bg as D,cC as S}from"./outputWidgets.781e41f9.js";import{B as $}from"./BaseLayout.afa95ff0.js";import{a as M}from"./asyncComputed.d06d5356.js";import{_ as N}from"./component.vue_vue_type_script_setup_true_lang.c89d053f.js";import"./authorManager.2805bec3.js";import{a as P}from"./build.e3a78b95.js";import"./index.fc2f40fb.js";import{P as R}from"./project.373df54c.js";import{O as V}from"./organization.ff3609a4.js";import{B as q,a as E,c as L}from"./index.3c3518df.js";import{A as O}from"./Text.6168f33a.js";import"./Log.e9aac728.js";import"./ant-design.e0bbd844.js";import"./index.609ad91a.js";import"./Modal.3a32e945.js";import"./StarFilled.fad29e50.js";import"./Timeline.31655e29.js";import"./WarningFilled.d99917ef.js";import"./Link.77931b3a.js";import"./index.db0f7a49.js";import"./log.7fb94d10.js";import"./TabPane.6d00c211.js";import"./hasIn.205b6afa.js";import"./index.82ed657d.js";import"./isNumeric.75337b1e.js";import"./icons.0ffc383b.js";import"./index.c9303d4d.js";import"./FormItem.341ebdb6.js";import"./index.cf4c23b9.js";import"./record.71f43d7d.js";import"./pubsub.2273fc34.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[s]="30016286-133f-4bb7-86ab-4d2d6e2e0dff",i._sentryDebugIdIdentifier="sentry-dbid-30016286-133f-4bb7-86ab-4d2d6e2e0dff")}catch{}})();const T={key:0},F={key:2},Bt=k({__name:"Build",setup(i){const s=B(),m=I(),c=s.params.buildId,{result:e,loading:f}=M(async()=>{const r=await P.get(c),p=await R.get(r.projectId),u=await V.get(p.organizationId);return j({bs:r,project:p,organization:u})}),b=w(()=>!f.value&&e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.organization.name,path:`/organizations/${e.value.organization.id}`},{label:`Build ${c.split("-")[0]}`,path:`/projects/${e.value.project.id}/builds`}]:void 0);function y(){var r;(r=e.value)!=null&&r.project.id&&m.push({name:"builds",params:{projectId:e.value.project.id}})}return(r,p)=>{const u=h("router-link");return a(),d($,null,{navbar:o(()=>[n(t(L),{title:"Inspect Build",style:{padding:"5px 25px"},onBack:y},{breadcrumb:o(()=>[b.value?(a(),d(t(q),{key:0},{default:o(()=>[(a(!0),l(C,null,x(b.value,(_,v)=>(a(),d(t(E),{key:v},{default:o(()=>[n(u,{to:_.path},{default:o(()=>[g(z(_.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):A("",!0)]),_:1})]),content:o(()=>[t(f)?(a(),l("div",T,[n(t(D))])):t(e)?(a(),d(N,{key:1,"build-spec":t(e).bs},null,8,["build-spec"])):(a(),l("div",F,[n(t(S),{direction:"vertical"},{default:o(()=>[n(t(O),null,{default:o(()=>[g("Could not find build")]),_:1})]),_:1})]))]),_:1})}}});export{Bt as default};
//# sourceMappingURL=Build.956ca7ff.js.map
