import"./outputWidgets.781e41f9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="79c74064-72ff-414a-9d0c-df4c0593c83e",e._sentryDebugIdIdentifier="sentry-dbid-79c74064-72ff-414a-9d0c-df4c0593c83e")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.a0d7eae0.js.map
