import{_ as c}from"./Sidebar.vue_vue_type_script_setup_true_lang.77f939de.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.d3014645.js";import{G as d,H as l,I as u}from"./icons.0ffc383b.js";import{d as b,eB as f,G as _,a as g,b as y,c as v,w as t,f as n}from"./outputWidgets.781e41f9.js";import{a as w}from"./asyncComputed.d06d5356.js";import"./authorManager.2805bec3.js";import"./index.fc2f40fb.js";import{O as z}from"./organization.ff3609a4.js";import{B as I}from"./BaseLayout.afa95ff0.js";import"./index.574af34c.js";import"./logo.084e5d7c.js";import"./Text.6168f33a.js";import"./index.3c3518df.js";import"./index.cf4c23b9.js";import"./record.71f43d7d.js";import"./pubsub.2273fc34.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="5eed02c9-bad9-4804-95a0-f90589cbe7e7",e._sentryDebugIdIdentifier="sentry-dbid-5eed02c9-bad9-4804-95a0-f90589cbe7e7")}catch{}})();const q=b({__name:"Organization",setup(e){const r=f().params.organizationId,{result:a}=w(()=>z.get(r)),i=_(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(h,B)=>{const m=g("router-view");return y(),v(I,null,{navbar:t(()=>[n(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[n(c,{class:"sidebar",sections:s})]),content:t(()=>[n(m)]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization.cd070ace.js.map
