import{N as b}from"./NavbarControls.a0781a92.js";import{d as _,eA as f,eB as y,G as g,a as v,b as c,ev as h,f as e,w as s,u as a,e as k,bq as w,aq as x,c as S,eU as q,v as A}from"./outputWidgets.781e41f9.js";import{A as B}from"./Text.6168f33a.js";import{T as C,A as o}from"./TabPane.6d00c211.js";import{c as I}from"./index.3c3518df.js";import"./asyncComputed.d06d5356.js";import"./index.dbc12d17.js";import"./pubsub.2273fc34.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.942344e3.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.5aeaa63f.js";import"./ant-design.e0bbd844.js";import"./index.609ad91a.js";import"./Modal.3a32e945.js";import"./Link.77931b3a.js";import"./index.1ca3acf8.js";import"./Title.bf1f8106.js";import"./index.0ad8ad84.js";import"./workspaces.3927864d.js";import"./record.71f43d7d.js";import"./url.a0d7eae0.js";import"./popupNotifcation.aa17bce8.js";import"./CircularLoading.091d9b3b.js";import"./icons.0ffc383b.js";import"./index.179a4456.js";import"./hasIn.205b6afa.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="070a81c6-d69b-44b2-980f-2c52c830e3a6",r._sentryDebugIdIdentifier="sentry-dbid-070a81c6-d69b-44b2-980f-2c52c830e3a6")}catch{}})();const T={class:"content"},D=_({__name:"Settings",setup(r){const t=f(),n=y();function m(){t.push({name:"home"})}const u=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function p(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(a(I),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(b,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(a(B),null,{default:s(()=>[x("Settings")]),_:1})]),footer:s(()=>[e(a(C),{"active-key":u.value,onChange:p},{default:s(()=>[e(a(o),{key:"style",tab:"Style"}),e(a(o),{key:"sidebar",tab:"Sidebar"}),e(a(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",T,[e(d,null,{default:s(({Component:l})=>[(c(),S(q(l)))]),_:1})])],64)}}});const re=A(D,[["__scopeId","data-v-772f4b10"]]);export{re as default};
//# sourceMappingURL=Settings.8b3eb6aa.js.map
